function ffmd_sync = ffmd_measure(ph,sampf)

% this function computes phase synchronization as the intensity of first 
% fourier mode of distribution of phases over an analysis window of fixed length

% inputs to this function - phase, sampling frequency
% output from this function - synchronization measure based on PLV
% processing performed - 
%  computes the Phase Locking Value for every interval of analysis, 
%  iterates over the entire time series oh phase difference values

% set window length over which the measure has to be computed
win_sec = 2; % in sec

% compute the window length
win_len = win_sec * sampf; % in no of samples

% get the total length of data
len = length(ph);

% convert phase to unit length phasor
data = exp(1j * ph);

% variable initialization
sync = zeros(1,len-win_len-1,'single');
cmpx_val = sum(data(1:win_len),1);
sync(1) = cmpx_val;

% compute FFMD measure for each analysis window
for k = 1:len-win_len-1
    % update the running measure
    cmpx_val = cmpx_val + data(k+win_len) - data(k);

    % store the measure for the current interval
    sync(k+1) = cmpx_val;
end

%compute the synchronization over a 0 to 1 measure
ffmd_sync = (abs(sync)/win_len).^2;

end