function result = hilbert_phase(input)
% this function computes the instantaenous hilbert transform based phase 
% known as hilbert phase for a given discrete time signal 

%input - discrete time series
%output - instantaneous hilbert phase as a time series
%processing - computes the complex valued analytic signal and extracts the
%argument of the complex time seires and limits the value to fundamental
%interval of 0 to 2*pi

% note: the hilbert phase extracted is relevant only when the times series 
% signal is band limited at a particular 

%need to provide the data in double format
data = double(input);

%perform hilbert transform on input data
tdata = hilbert(data);

%obtain hilbert phase in radians
%note: the values ranges from -pi to +pi radians
output = atan2(imag(tdata),real(tdata));

%note: the phase will now range from 0 to 2 pi radians
result = mod(output,2*pi);

end