function sync = hilbert_phase_synch(ch1,ch2,sampf,H_filter)
% this function computes the hilbert transform based phase synchronization
% measure over a specific frequency band of interest between two discrete
% time signals at a particular sampling frequency

% input required by this module - 
%     input channels and sampling frequency
% output supplied by this module - none

% action performed - filter the input data for - frequency band of interest,
% suppress line noise, etc.

% perform filtering using filtfilt function for zero phase distortion
% note:resulting transfer function is the squared magnitude of the original
disp 'filtering data..'
% process channel 1 data
data = double(ch1);
ch1_filt = filtfilt(H_filter,1,data);
% process channel 2 data
data = double(ch2);
ch2_filt = filtfilt(H_filter,1,data);
disp ' '

% call function to compute hilbert phase
% process channel 1 data
disp 'computing hilbert phase'
ch1_ph = hilbert_phase(ch1_filt);
% process channel 2 data
ch2_ph = hilbert_phase(ch2_filt);

% compute phase difference between the two channels and express the result
% uniquely in the range of 0 to 2pi rad
disp 'computing phase difference'
ph_diff = mod(ch1_ph-ch2_ph,2*pi);

% call function to compute synchronization level

% phase locking value based phase synchronization measure
disp 'evaluating phase sync..'
sync = ffmd_measure(ph_diff,sampf);
disp ' '

end
